translate.storage.versioncontrol.cvs.cvs

Package translate :: Package storage :: Package versioncontrol :: Module cvs :: Class cvs |
[hide private]
[frames] | no frames]

# Class cvs

source code

Class to manage items under revision control of CVS.

Instance Methods | [hide private]
_readfile(self, cvsroot, path, revision=None) Read a single file from the CVS repository without checking out a full working directory. | source code
getcleanfile(self, revision=None) Get the content of the file for the given revision | source code
update(self, revision=None) Does a clean update of the given path | source code
commit(self, message=None, author=None) Commits the file and supplies the given commit message if present | source code
_getcvsrevision(self, cvsentries) returns the revision number the file was checked out with by looking in the lines of cvsentries | source code
_getcvstag(self, cvsentries) Returns the sticky tag the file was checked out with by looking in the lines of cvsentries. | source code
Inherited from `GenericRevisionControlSystem`: `__init__` Inherited from `GenericRevisionControlSystem` (private): `_find_rcs_directory`, `_find_rcs_in_parent_directories`, `_self_check`

Class Variables | [hide private]
| RCS_METADIR = ``'``CVS``'`` The name of the metadata directory of the RCS
| SCAN_PARENTS = `False` whether to check the parent directories for the metadata directory of the RCS working copy

Method Details | [hide private]

### _readfile(self, cvsroot, path, revision=None) | source code
Read a single file from the CVS repository without checking out a full working directory. Parameters: `cvsroot` - the CVSROOT for the repository `path` - path to the file relative to cvs root `revision` - revision or tag to get (retrieves from HEAD if None)

### getcleanfile(self, revision=None) | source code
Get the content of the file for the given revision Overrides: GenericRevisionControlSystem.getcleanfile

### update(self, revision=None) | source code
Does a clean update of the given path Overrides: GenericRevisionControlSystem.update

### commit(self, message=None, author=None) | source code
Commits the file and supplies the given commit message if present the 'author' parameter is not suitable for CVS, thus it is ignored Overrides: GenericRevisionControlSystem.commit